pub struct Baggage { /* private fields */ }Expand description
Baggage is key-value pairs that propagate across the network
Implementations
Sourceimpl Baggage
impl Baggage
Sourcepub fn set(&mut self, key: impl Into<String>, value: impl Into<String>)
pub fn set(&mut self, key: impl Into<String>, value: impl Into<String>)
Insert or replace a baggage entry by key
Sourcepub fn set_with_metadata(
&mut self,
key: impl Into<String>,
value: impl Into<String>,
metadata: impl Into<String>,
)
pub fn set_with_metadata( &mut self, key: impl Into<String>, value: impl Into<String>, metadata: impl Into<String>, )
Insert or replace a baggage entry with associated metadata properties
Sourcepub fn get_with_metadata(&self, key: &str) -> Option<(&str, Option<&str>)>
pub fn get_with_metadata(&self, key: &str) -> Option<(&str, Option<&str>)>
Look up a baggage value and its optional metadata by key
Sourcepub fn remove(&mut self, key: &str) -> Option<String>
pub fn remove(&mut self, key: &str) -> Option<String>
Remove a baggage entry by key and return its value