ContextScope

Struct ContextScope 

pub struct ContextScope<'a> { /* private fields */ }
Context scope for automatic span management

Implementations

Source

impl<'a> ContextScope<'a>

pub fn new( store: &'a ContextStore, ctx: &Context, name: &str, node_id: NodeId, ) -> Self

Create a new scope that automatically records a span on drop

pub fn with_kind(self, kind: SpanKind) -> Self

Set the kind of the underlying span

pub fn set_attribute( &mut self, key: impl Into<String>, value: impl Into<AttributeValue>, )

Set an attribute on the underlying span

pub fn add_event(&mut self, name: impl Into<String>)

Record a named event on the underlying span

pub fn set_ok(&mut self)

Mark the underlying span as successfully completed

pub fn set_error(&mut self, message: impl Into<String>)

Mark the underlying span as failed with the given message

pub fn finish(self)

Explicitly finish the scope and submit the span to the store

pub fn span(&self) -> &Span

Return a reference to the underlying span