pub enum PredicateWireError {
Empty,
RootOutOfBounds {
root_idx: u32,
len: usize,
},
ChildOutOfBounds {
child: u32,
len: usize,
},
CycleDetected {
parent: u32,
child: u32,
},
}Expand description
Errors raised by PredicateWire::into_predicate.
Variants
Empty
Wire payload had an empty nodes table.
RootOutOfBounds
root_idx was out of bounds for the nodes table.
ChildOutOfBounds
A composite node referenced a child index that was out of bounds.
CycleDetected
A composite node referenced a child index that was greater than or equal to its own. Catches index cycles introduced by malformed / malicious wire payloads.