pub enum AttestationBridgeError {
CapabilityMismatch,
InterestDigestMismatch,
}Expand description
Why a wire attestation could not be bridged onto a validated
interest (semantic_attestation).
Variants
CapabilityMismatch
The attestation names a different capability than the validated interest key.
InterestDigestMismatch
The attestation answers a different interest digest than the validated interest key.