connected_udp_socket

Function connected_udp_socket 

pub async fn connected_udp_socket(target: SocketAddr) -> Result<UdpSocket>
Binds a UDP socket and connects it to target.

Connecting the socket makes the kernel drop any packet that does not come from target, which is the source validation RFC 9298 3.1 calls for.