pub struct HttpCache { /* private fields */ }Expand description
A simple memory cache.
Elements will be evicted based on the cache heuristic. We weight elements
by the number of entries per given url. We evict currently a whole url.
The cache makes extensive use of Arc::unwrap_or_clone or and Arc::into_inner
to modify the cached entries. This is ok because CachedResource are cheap to clone
Implementations
Sourceimpl HttpCache
impl HttpCache
Sourcepub async fn store(&self, request: &Request, response: &Response)
pub async fn store(&self, request: &Request, response: &Response)
Insert a response for request into the cache (used by tests that need direct access).
Sourcepub async fn construct_response(
&self,
request: &Request,
done_chan: &mut DoneChannel,
) -> Option<Response>
pub async fn construct_response( &self, request: &Request, done_chan: &mut DoneChannel, ) -> Option<Response>
Try to construct a cached response for request.
Sourcepub async fn get_or_guard(
&self,
entry_key: CacheKey,
) -> CachedResourcesOrGuard<'_>
pub async fn get_or_guard( &self, entry_key: CacheKey, ) -> CachedResourcesOrGuard<'_>
If the value exist in the cache, return it. If the value does not exist, return a guard you can use to insert values in the cache. If the guard is alive, all other accesses to this function will block.