pub struct AdaptiveBatcher { /* private fields */ }Expand description
Adaptive batch size calculator.
Tracks recent ingestion velocity and adjusts batch size accordingly.
Implementations
Sourceimpl AdaptiveBatcher
impl AdaptiveBatcher
Sourcepub fn new(config: BatchConfig) -> Self
pub fn new(config: BatchConfig) -> Self
Create a new adaptive batcher.
Sourcepub fn record_events(&mut self, count: usize) -> usize
pub fn record_events(&mut self, count: usize) -> usize
Record events and get the current target batch size.
Call this each time events are drained from the ring buffer.
Sourcepub fn batch_size(&self) -> usize
pub fn batch_size(&self) -> usize
Get the current target batch size.