Structs
- Async
Runtime Holder - The actual runtime, to be used as part of shut-down.
Functions
- async_
runtime_ initialized - init_
async_ runtime - spawn_
blocking_ task - Spawn a blocking task using the handle to the runtime.
- spawn_
task - Spawn a task using the handle to the runtime.