A memory cache implementing the logic specified in http://tools.ietf.org/html/rfc7234 and http://tools.ietf.org/html/rfc7232.
Structs
- Cache
Key - The key used to differentiate requests in the cache.
- Cached
Resource - A complete cached resource.
- Http
Cache - A simple memory cache.
Elements will be evicted based on the cache heuristic. We weight elements
by the number of entries per given url. We evict currently a whole url.
The cache makes extensive use of
Arc::unwrap_or_clone orandArc::into_innerto modify the cached entries. This is ok becauseCachedResourceare cheap to clone
Enums
- Cached
Resources OrGuard - Returns an writeable entry into the cache or a guard for insertint an entry The guard will block other queries to the cache entry in both cases.
Functions
- refresh
- Freshening Stored Responses upon Validation. https://tools.ietf.org/html/rfc7234#section-4.3.4