Module image_cache

Module image_cache 

Structs

ImageCacheFactoryImpl
ImageCacheImpl

Constants

SUPPRESS_ABORT_IN_PANIC_HOOK

Functions

should_panic_hook_suppress_termination
Returns true if embedder’s custom panic hook handler should not treat the panic as a fatal error that requires termination of the engine.