Structs
Constants
Functions
- should_
panic_ hook_ suppress_ termination - Returns
trueif embedder’s custom panic hook handler should not treat the panic as a fatal error that requires termination of the engine.
true if embedder’s custom panic hook handler should not treat the panic
as a fatal error that requires termination of the engine.